package com.altinity.opsview.odw;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;

import com.altinity.opsview.odw.exception.InvalidUsageException;


public class ODWReportLauncher {
	
	/**
	 * 
	 */
	public static void main(String [] args) {
		
		BasicConfigurator.configure();
		Logger.getRootLogger().setLevel(Level.DEBUG);
		
		boolean success = false;
		CommandLineParams cmdLineParams = null;
		try {
			
			// Check if command line params are valid, if not print usage
			cmdLineParams = new CommandLineParams(args);
			if ( !cmdLineParams.isValid() ) {
				cmdLineParams.usage();	
				return;
			}
			
			System.out.println("ODWReportLauncher starting...");
			System.out.println("Using report id: '" + cmdLineParams.getReportId() + "'");
			
			// Load up and init ODWReportGenerator
			ODWReportGenerator generator = SpringLoader.loadConfig(cmdLineParams.getFileName());
			
			// Now execute the report
			success = generator.generateReport(cmdLineParams);
		}
		catch(InvalidUsageException e) {
			cmdLineParams.usage();
			return;
		}
		catch(Exception e) {
			e.printStackTrace();
			throw new RuntimeException(e);
		}
		
		if ( success )
			System.out.println("ODWReportLauncher DONE!");
		else
			System.out.println("Errors reported in ODWReportLauncher - unable to continue");
	}
}
