package com.altinity.opsview.odw.dao;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

public class QueryBuilder {
	
	/**
	 * 
	 */
	public static String getQueryForHostDescription() {
	
		StringBuffer query = new StringBuffer();
		query.append("select distinct hosts.alias as alias ");
		query.append("from hosts ");
		query.append("where hosts.name=? ");
		return query.toString();
	}
	
	/**
	 * 
	 */
	public static String getQueryForPerformanceData() {
		
		StringBuffer query = new StringBuffer();
		query.append("select CONVERT_TZ(performance_data.datetime,'+00:00','SYSTEM') as date, performance_data.value as value ");
		query.append("from hosts, servicechecks, performance_labels, performance_data ");
		query.append("where hosts.name=? ");
		query.append("and servicechecks.name=? ");
		query.append("and performance_labels.name=? ");
		query.append("and hosts.id = servicechecks.host ");
		query.append("and servicechecks.id = performance_labels.servicecheck ");
		query.append("and performance_labels.id = performance_data.performance_label ");
		query.append("and CONVERT_TZ(performance_data.datetime,'+00:00','SYSTEM') > DATE(?) ");
		query.append("and CONVERT_TZ(performance_data.datetime,'+00:00','SYSTEM') < DATE(?) ");
		query.append("order by date");
		return query.toString();
	}
	
	/**
	 * 
	 */
	public static String getQueryForStateHistory() {
		
		StringBuffer query = new StringBuffer();
		query.append("select CONVERT_TZ(state_history.datetime,'+00:00','SYSTEM') as date, state_history.status as status ");
		query.append("from hosts, servicechecks, state_history ");
		query.append("where hosts.name=? ");
		query.append("and servicechecks.name=? ");
		query.append("and hosts.id = servicechecks.host ");
		query.append("and servicechecks.id = state_history.servicecheck ");
		query.append("and CONVERT_TZ(state_history.datetime,'+00:00','SYSTEM') > DATE(?) ");
		query.append("and CONVERT_TZ(state_history.datetime,'+00:00','SYSTEM') < DATE(?) ");		
		query.append("order by datetime");
		return query.toString();
	}
	
	/**
	 * 
	 */
	public static String getQueryForPriorStatus() {
		
		StringBuffer query = new StringBuffer();
		query.append("select prior_status as status ");
		query.append("from hosts, servicechecks, state_history ");
		query.append("where hosts.name=? ");
		query.append("and servicechecks.name=? ");
		query.append("and hosts.id = servicechecks.host ");
		query.append("and servicechecks.id = state_history.servicecheck ");
		query.append("and CONVERT_TZ(state_history.datetime,'+00:00','SYSTEM') = TIMESTAMP(?) ");
		return query.toString();
	}
	
	/**
	 * 
	 */
	public static String getQueryForHourSummary() {
		
		StringBuffer query = new StringBuffer();
		query.append("select seconds_ok, seconds_warning, seconds_unknown, seconds_critical ");
		query.append("from hosts, servicechecks, service_availability_hourly_summary ");
		query.append("where hosts.name=? ");
		query.append("and servicechecks.name=? ");
		query.append("and hosts.id = servicechecks.host ");
		query.append("and servicechecks.id = service_availability_hourly_summary.servicecheck ");
		query.append("and CONVERT_TZ(service_availability_hourly_summary.start_datetime,'+00:00','SYSTEM') = TIMESTAMP(?) ");
		return query.toString();
	}
	
	/**
	 * select hostgroup as hostGroup,
	 * percent_total_time_okay as percentOK, 
	 * percent_total_scheduled_downtime as percentSched, 
	 * percent_total_unscheduled_downtime as percentUnsched,
	 * date
	 * from availability_hostgroup_summary
	 * where date >= CURDATE() - interval 7 day
	 */
	public static String getAllForWeek(String startDate) {
		
		StringBuffer query = new StringBuffer();
		query.append("select percent_total_time_okay as percentOK,");
		query.append(" percent_total_scheduled_downtime as percentSched,");
		query.append(" percent_total_unscheduled_downtime as percentUnsched");
		query.append(" from availability_hostgroup_summary");
		query.append(" where (date > DATE('" + startDate + "') - interval 7 day)");
		query.append(" and (date <= DATE('" + startDate + "'))");
		return query.toString();
	}
	
	/**
	 * select percent_total_time_okay as percentOK,
	 * percent_total_scheduled_downtime as percentSched,
	 * percent_total_unscheduled_downtime as percentUnsched,
	 * date
	 * from availability_hostgroup_summary
	 * where date >= CURDATE() - interval 28 day
	 */
	public static String getAllForMonth(String startDate) {
		
		StringBuffer query = new StringBuffer();
		query.append("select date, percent_total_time_okay as percentOK,");
		query.append(" percent_total_scheduled_downtime as percentSched,");
		query.append(" percent_total_unscheduled_downtime as percentUnsched");
		query.append(" from availability_summary");
		query.append(" where (date > DATE('" + startDate + "') - interval 28 day)");
		query.append(" and (date <= DATE('" + startDate + "'))");
		query.append(" order by date");
		return query.toString();
	}
	
	/**
	 * select percent_total_time_okay as percentOK, date
	 * from availability_summary
	 * where date >= CURDATE() - interval 28 day
	 */
	public static String getPerecentOKForWeek(String startDate) {
		
		StringBuffer query = new StringBuffer();
		query.append("select date,");
		query.append(" percent_total_time_okay as percentOK");
		query.append(" from availability_summary");
		query.append(" where (date > DATE('" + startDate + "') - interval 28 day)");
		query.append(" and (date <= DATE('" + startDate + "'))");
		return query.toString();
	}
	
	/**
	 * Return comments for paragraph with specified key
	 */
	public static String getComments(String commentsKey) {
		
		StringBuffer query = new StringBuffer();
		query.append("select text");
		query.append(" from report_comments");
		query.append(" where name = \'" + commentsKey + "\'");
		return query.toString();
	}
	
	/**
	 * 
	 */
	public static String getCommentsCheck(String startDate) {
		
		StringBuffer query = new StringBuffer();
		query.append("select CONVERT_TZ(comment_time,'+00:00','SYSTEM') as comment_time");
		query.append(" from runtime.nagios_commenthistory");
		query.append(" where (CONVERT_TZ(comment_time,'+00:00','SYSTEM') > DATE('" + startDate + "') - interval 7 day)");
		query.append(" and (CONVERT_TZ(comment_time,'+00:00','SYSTEM') <= DATE('" + startDate + "'))");
		return query.toString();
	}
}
