package com.altinity.opsview.odw.elements;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.util.Calendar;
import java.util.List;

import org.dom4j.Element;
import org.jfree.chart.JFreeChart;

import com.altinity.opsview.jfreechart.ThresholdWeekChart;
import com.altinity.opsview.odw.ReportConstants;
import com.altinity.opsview.odw.bc.ODWReportLogger;
import com.altinity.opsview.odw.dao.ODWReportConfigDAO;
import com.altinity.opsview.odw.dao.ODWReportDAO;
import com.altinity.opsview.odw.exception.ReportException;
import com.altinity.opsview.odw.reports.ReportCriteria;
import com.excira.jfreechart.XYPoint;

public class AverageAvailabilityChart extends AbstractReportElement implements ReportConstants{
	
	private List <XYPoint> xyPoints;

	/**
	 * 
	 */
	public AverageAvailabilityChart(ReportCriteria rc, ODWReportDAO dao, ODWReportConfigDAO configDao, ODWReportLogger log) {
		super(rc, dao, configDao, log);
	}

	/**
	 * 
	 */
	@Override
	public 	Element addElement(Element elements) {
		
		// First create element
		Element averageAvailabilityGraph= elements.addElement("element");
		averageAvailabilityGraph.addAttribute("name", "averageAvailabilityGraph");
		averageAvailabilityGraph.addElement("title").setText("Daily Availability, Last 4 Months");
		
		// If no data has been found, add empty element and report error
		if ( xyPoints.isEmpty() ) {
			
			// Add empty element
			averageAvailabilityGraph.addElement("empty").setText("true");
			
			// Report error
			log.getErrors().add("No data found for module 'Daily Availability, Last 4 Months'");
		}
		// Data has been found
		// Generate average availability chart
		else {
			
			// Chart is plotted over a period of four months
			// Get the correct start date for the date range
			Calendar cal = Calendar.getInstance();
			cal.setTime(rc.getReportStartDate());
			cal.add(Calendar.MONTH, -3);
			
			// Set thresholds to be 0 as we do not want any thresholds to be
			// displayed on this chart
			ThresholdWeekChart weekChart =
				new ThresholdWeekChart(0d, 0d, cal.getTime(), rc.getReportEndDate());
			
			JFreeChart chart = weekChart.createChart("", "Availability %", xyPoints, true);
			String fileName = saveImageToTempDir(chart, "averageAvailability");
			averageAvailabilityGraph.addElement("image").setText(fileName);
		}
		
		return averageAvailabilityGraph;
	}
	
	/**
	 * 
	 */
	public void runQuery() throws ReportException {
		
		xyPoints = dao.getAverageAvailabilityTimeSeries(configDao, rc);
	}
}
